@@ -3,12 +3,12 @@
  * Author: Igor Vlasenko <vlasenko@imath.kiev.ua>
  * Created: Thu May 26 15:25:57 2005
  *
- * $Id: proscope.c,v 1.3 2005/06/16 17:07:30 igor Exp $
+ * $Id: proscope.c,v 1.4 2005/09/30 11:00:37 igor Exp $
  */
 
-#include <stdio.h>
 #include <stdlib.h>
 #include "proscope.h"
+#include "tmpllog.h"
 
 int ScopeLevel=-1;
 int ScopeMax=-1;
@@ -22,12 +22,11 @@ struct ProLoopState* CurrentScope;
 void Scope_init() {
   ScopeMax=START_NUMBER_OF_NESTED_LOOPS;
   Scope=(struct ProLoopState*) malloc (ScopeMax * sizeof(struct ProLoopState));
-  if (NULL==Scope) fprintf(stderr, "DIE:Scope_init:internal error:not enough memory\n");
+  if (NULL==Scope) tmpl_log(NULL,TMPL_LOG_ERROR, "DIE:Scope_init:internal error:not enough memory\n");
   ScopeLevel=-1;
 }
 
 void Scope_free() {
-  /* fprintf(stderr, "Scope_free done\n"); */
   free(Scope);
   ScopeMax=-1;
   ScopeLevel=-1;
@@ -43,14 +42,14 @@ struct ProLoopState* GetScope(int depth) {
 
 void PopScope() {
   if (ScopeLevel>0) ScopeLevel--;
-  else fprintf(stderr, "WARN:PopScope:internal error:scope is exhausted\n");
+  else tmpl_log(NULL,TMPL_LOG_ERROR, "WARN:PopScope:internal error:scope is exhausted\n");
   set_CurrentScope();
 }
 
 void PushScope2(int maxloop, void *loops_AV) {
   if (ScopeMax<0) {
     
-    fprintf(stderr, "WARN:PushScope:internal warning:why scope is empty?\n");
+    tmpl_log(NULL,TMPL_LOG_ERROR, "WARN:PushScope:internal warning:why scope is empty?\n");
     Scope_init();
   }
   ++ScopeLevel;
@@ -69,7 +68,7 @@ void PushScope2(int maxloop, void *loops_AV) {
 
 void SetRootScope(void* param_HV) {
   if (ScopeMax<0) {
-    fprintf(stderr, "WARN:SetRootScope:internal warning:why scope is empty?\n");
+    tmpl_log(NULL,TMPL_LOG_ERROR, "WARN:SetRootScope:internal warning:why scope is empty?\n");
     Scope_init();
   }
   ScopeLevel=0;
